@@ -18,7 +18,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
+#include "config.h"
 #include "gconf-internals.h"
 #include "gconf-backend.h"
 #include "gconf-schema.h"
@@ -2796,7 +2796,7 @@ gconf_get_daemon_dir (void)
     {
       char *s;
       char *subdir;
-      char *tmpdir;
+      const char *tmpdir;
 
       subdir = g_strconcat ("gconfd-", g_get_user_name (), NULL);
       
@@ -2841,7 +2841,6 @@ gconf_activate_server (gboolean  start_if_not_found,
                        GError  **error)
 {
   ConfigServer server = CORBA_OBJECT_NIL;
-  GError *tmp_err;
   GString *failure_log;
   CORBA_Environment ev;
 
@@ -2875,14 +2874,13 @@ gconf_activate_server (gboolean  start_if_not_found,
       return server;
     }
 
- out:
   if (server == CORBA_OBJECT_NIL &&
       error &&
       *error == NULL)
     g_set_error (error,
                  GCONF_ERROR,
                  GCONF_ERROR_NO_SERVER,
-                 _("Failed to contact configuration server; some possible causes are that you need to enable TCP/IP networking for ORBit, or you have stale NFS locks due to a system crash. See http://www.gnome.org/projects/gconf/ for information. (Details - %s)"),
+                 _("Failed to contact configuration server; some possible causes are that you need to enable TCP/IP networking for ORBit, or you have stale NFS locks due to a system crash. See http://project.gnome.org/gconf/ for information. (Details - %s)"),
                  failure_log->len > 0 ? failure_log->str : _("none"));
 
   g_string_free (failure_log, TRUE);
